# Introduction
Item Matching tool

# How to setup
Create your environment with mamba
```
mamba create -n <your_name> python=3.11 -y && mamba activate <your_name>
```

Install with pip:
```
pip install item-matching
```
